@@ -1,3 +1,85 @@
+"""
+## AWS Key Management Service Construct Library
+
+<html></html>---
+
+
+![Stability: Stable](https://img.shields.io/badge/stability-Stable-success.svg?style=for-the-badge)
+
+---
+<html></html>
+
+Define a KMS key:
+
+```python
+# Example may have issues. See https://github.com/aws/jsii/issues/826
+import aws_cdk.aws_kms as kms
+
+kms.Key(self, "MyKey",
+    enable_key_rotation=True
+)
+```
+
+Add a couple of aliases:
+
+```python
+# Example may have issues. See https://github.com/aws/jsii/issues/826
+key = kms.Key(self, "MyKey")
+key.add_alias("alias/foo")
+key.add_alias("alias/bar")
+```
+
+### Sharing keys between stacks
+
+To use a KMS key in a different stack in the same CDK application,
+pass the construct to the other stack:
+
+```python
+# Example may have issues. See https://github.com/aws/jsii/issues/826
+
+#
+# Stack that defines the key
+#
+class KeyStack(cdk.Stack):
+
+    def __init__(self, scope, id, props=None):
+        super().__init__(scope, id, props)
+        self.key = kms.Key(self, "MyKey", removal_policy=RemovalPolicy.DESTROY)
+
+#
+# Stack that uses the key
+#
+class UseStack(cdk.Stack):
+    def __init__(self, scope, id, *, key):
+        super().__init__(scope, id, key=key)
+
+        # Use the IKey object here.
+        kms.Alias(self, "Alias",
+            alias_name="alias/foo",
+            target_key=key
+        )
+
+key_stack = KeyStack(app, "KeyStack")
+UseStack(app, "UseStack", key=key_stack.key)
+```
+
+### Importing existing keys
+
+To use a KMS key that is not defined in this CDK app, but is created through other means, use
+`Key.fromKeyArn(parent, name, ref)`:
+
+```python
+# Example may have issues. See https://github.com/aws/jsii/issues/826
+my_key_imported = kms.Key.from_key_arn(self, "MyImportedKey", "arn:aws:...")
+
+# you can do stuff with this imported key.
+my_key_imported.add_alias("alias/foo")
+```
+
+Note that a call to `.addToPolicy(statement)` on `myKeyImported` will not have
+an affect on the key's policy because it is not owned by your stack. The call
+will be a no-op.
+"""
 import abc
 import datetime
 import enum
@@ -11,7 +93,7 @@ from jsii.python import classproperty
 
 import aws_cdk.aws_iam
 import aws_cdk.core
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "1.15.0", __name__, "aws-kms@1.15.0.jsii.tgz")
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-cdk/aws-kms", "1.16.0", __name__, "aws-kms@1.16.0.jsii.tgz")
 @jsii.data_type(jsii_type="@aws-cdk/aws-kms.AliasAttributes", jsii_struct_bases=[], name_mapping={'alias_name': 'aliasName', 'alias_target_key': 'aliasTargetKey'})
 class AliasAttributes():
     def __init__(self, *, alias_name: str, alias_target_key: "IKey"):
@@ -96,6 +178,7 @@ class AliasProps():
         return 'AliasProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnAlias(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.CfnAlias"):
     """A CloudFormation ``AWS::KMS::Alias``.
 
@@ -117,6 +200,17 @@ class CfnAlias(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aw
 
         jsii.create(CfnAlias, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
@@ -208,6 +302,7 @@ class CfnAliasProps():
         return 'CfnAliasProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
+@jsii.implements(aws_cdk.core.IInspectable)
 class CfnKey(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-cdk/aws-kms.CfnKey"):
     """A CloudFormation ``AWS::KMS::Key``.
 
@@ -234,6 +329,17 @@ class CfnKey(aws_cdk.core.CfnResource, metaclass=jsii.JSIIMeta, jsii_type="@aws-
 
         jsii.create(CfnKey, self, [scope, id, props])
 
+    @jsii.member(jsii_name="inspect")
+    def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
+        """Examines the CloudFormation resource and discloses attributes.
+
+        :param inspector: - tree inspector to collect and process attributes.
+
+        stability
+        :stability: experimental
+        """
+        return jsii.invoke(self, "inspect", [inspector])
+
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(self, props: typing.Mapping[str,typing.Any]) -> typing.Mapping[str,typing.Any]:
         """
